/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package com.funambol.framework.core.bootstrap;

import java.io.Serializable;

import org.apache.commons.lang.builder.ToStringBuilder;

/**
 * Contains the info to bootstrap a device.
 *
 *
 * @version $Id: BootStrap.java,v 1.1 2006/01/18 18:38:11 luigiafassina Exp $
 */
public class BootStrap implements Serializable {

    // -------------------------------------------------------------- Properties
    private String  msisdn;
    private String  username;
    private String  password;
    private String  deviceId;
    private String  imsi;
    private String  userPin;
    private byte[]  bootstrapMessage;
    private String  digest;
    private int     authMethod;
    private boolean imsiInSemiOctet;

    /**
     * Gets the msisdn
     * @return the msisdn
     */
    public String getMsisdn() {
        return msisdn;
    }

    /**
     * Sets the msisdn
     * @param msisdn the msisdn to sets
     */
    public void setMsisdn(String msisdn) {
        this.msisdn = msisdn;
    }

    /**
     * Gets the username
     * @return the username
     */
    public String getUsername() {
        return username;
    }

    /**
     * Sets the username
     * @param username the username to sets
     */
    public void setUsername(String username) {
        this.username = username;
    }

    /**
     * Gets the password
     * @return the password
     */
    public String getPassword() {
        return password;
    }

    /**
     * Sets the password
     * @param password the password to sets
     */
    public void setPassword(String password) {
        this.password = password;
    }

    /**
     * Gets the deviceId
     * @return the deviceId
     */
    public String getDeviceId() {
        return deviceId;
    }

    /**
     * Sets the deviceId
     * @param deviceId the deviceId to sets
     */
    public void setDeviceId(String deviceId) {
        this.deviceId = deviceId;
    }

    /**
     * Gets the imsi
     * @return the imsi
     */
    public String getImsi() {
        return imsi;
    }

    /**
     * Sets the imsi
     * @param imsi the imsi to sets
     */
    public void setImsi(String imsi) {
        this.imsi = imsi;
    }

    /**
     * Gets the bootstrapMessage
     * @return the bootstrapMessage
     */
    public byte[] getBootstrapMessage() {
        return bootstrapMessage;
    }

    /**
     * Sets the bootstrapMessage
     * @param bootstrapMessage the bootstrapMessage to sets
     */
    public void setBootstrapMessage(byte[] bootstrapMessage) {
        this.bootstrapMessage = bootstrapMessage;
    }

    /**
     * Gets the digest
     * @return the digest
     */
    public String getDigest() {
        return digest;
    }

    /**
     * Sets the digest
     * @param digest the digest to sets
     */
    public void setDigest(String digest) {
        this.digest = digest;
    }

    /**
     * Gets the authMethod
     * @return the authMethod
     */
    public int getAuthMethod() {
        return authMethod;
    }

    /**
     * Sets the authMethod
     * @param authMethod the authMethod to sets
     */
    public void setAuthMethod(int authMethod) {
        this.authMethod = authMethod;
    }

    /**
     * Gets the imsiInSemiOctet
     * @return the imsiInSemiOctet
     */
    public boolean isImsiInSemiOctet() {
        return imsiInSemiOctet;
    }

    /**
     * Sets if the imsi must be codified in semi-octet
     * @param imsiInSemiOctet the imsi must be codified in semi-octet ?
     */
    public void setImsiInSemiOctet(boolean imsiInSemiOctet) {
        this.imsiInSemiOctet = imsiInSemiOctet;
    }

    /**
     * Gets the userPin
     * @return the userPin
     */
    public String getUserPin() {
        return userPin;
    }

    /**
     * Sets the userPin
     * @param userPin the userPin to sets
     */
    public void setUserPin(String userPin) {
        this.userPin = userPin;
    }

    // ------------------------------------------------------------ Constructors

    /**
     * Creates a new Bootstrap
     */
    public BootStrap() {
    }

    /**
     * Creates a new Bootstrap with the given parameters
     */
    public BootStrap(String  msisdn,
                     String  username,
                     String  password,
                     String  deviceId,
                     String  imsi,
                     String  userPin,
                     byte[]  bootstrapMessage,
                     String  digest,
                     int     authMethod,
                     boolean imsiInSemiOctet) {

        this.msisdn           = msisdn;
        this.username         = username;
        this.password         = password;
        this.deviceId         = deviceId;
        this.imsi             = imsi;
        this.userPin          = userPin;
        this.bootstrapMessage = bootstrapMessage;
        this.digest           = digest;
        this.authMethod       = authMethod;
        this.imsiInSemiOctet  = imsiInSemiOctet;

    }

    // --------------------------------------------------------- Pubblic Methods

    /**
     * Returns a String representation of this Bootstrap
     * @return String
     */
    public String toString() {
        ToStringBuilder sb = new ToStringBuilder(this);

        sb.append("msisdn"  , msisdn);
        sb.append("username", username);
        sb.append("password", password);
        sb.append("deviceId", deviceId);
        sb.append("imsi"    , imsi);
        sb.append("userPin" , userPin);
        sb.append("authMethod" , authMethod);
        sb.append("bootstrapMessage", bootstrapMessage);
        sb.append("digest"  , digest);
        sb.append("imsiInSemiOctet" , imsiInSemiOctet);


        return sb.toString();
    }


}
