/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package com.funambol.framework.core.bootstrap;

import java.util.ArrayList;


/**
 * Corresponds to the &lt;characteristic&gt; tag in a Wap provisioning doc.
 *
 *
 *
 * @version $Id: Characteristic.java,v 1.1 2006/01/18 18:38:11 luigiafassina Exp $
 *
 */
public final class Characteristic {

    // --------------------------------------------------------------- Constants
    public static final String TYPE_PXLOGICAL          = "PXLOGICAL";
    public static final String TYPE_PXPHYSICAL         = "PXPHYSICAL";
    public static final String TYPE_PXAUTHINFO         = "PXAUTHINFO";
    public static final String TYPE_PORT               = "PORT";
    public static final String TYPE_NAPDEF             = "NAPDEF";
    public static final String TYPE_NAPAUTHINFO        = "NAPAUTHINFO";
    public static final String TYPE_VALIDITY           = "VALIDITY";
    public static final String TYPE_BOOTSTRAP          = "BOOTSTRAP";
    public static final String TYPE_CLIENTIDENTITY     = "CLIENTIDENTITY";
    public static final String TYPE_VENDORCONFIG       = "VENDORCONFIG";
    public static final String TYPE_APPLICATION        = "APPLICATION";
    public static final String TYPE_APPADDR            = "APPADDR";
    public static final String TYPE_APPAUTH            = "APPAUTH";
    public static final String TYPE_RESOURCE           = "RESOURCE";
    public static final String TYPE_ACCESS             = "ACCESS";



    // -------------------------------------------------------------- Properties

    private ArrayList childs;

    private String type;

    // ------------------------------------------------------------ Constructors

    public Characteristic() {
        childs = new ArrayList();
    }

    public Characteristic(String type) {
        this();
        this.type = type;
    }


    /**
     * Adds new <code>Characteristic</code> to this characteristic
     * @param characteristicToAdd the characteristic to add
     */
    public void add(Characteristic characteristicToAdd) {
        childs.add(characteristicToAdd);
    }

    /**
     * Adds new <code>Parm</code> to this characteristic
     * @param parmToAdd the parm to add
     */
    public void add(Parm parmToAdd) {
        childs.add(parmToAdd);
    }

    /**
     * Gets the type
     * @return the type of this characteristic
     */
    public String getType() {
        return type;
    }

    /**
     * Sets the type of this characteristic
     * @param type the type to sets
     */
    public void setType(String type) {
        this.type = type;
    }

}
