/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package com.funambol.framework.core.dm.ddf;

import java.util.Map;

import org.apache.commons.collections.map.ListOrderedMap;


/**
 * Corresponds to the &lt;Con&gt; interior node in the management tree
 *
 *
 *
 * @version $Id: ConNode.java,v 1.1 2006/01/18 18:38:11 luigiafassina Exp $
 */
public class ConNode implements java.io.Serializable {

    // --------------------------------------------------------------- Constants


    // ------------------------------------------------------------ Private data

    private Map connections;

    // ------------------------------------------------------------ Constructors
    /** For serialization purposes */
    public ConNode() {
        this.connections = new ListOrderedMap();
    }

     /**
      * Creates a new ConNode object with the given <code>Connection</code> and the given name
      *
      * @param con the connection node
      * @param connectionName the connection name
      */
     public ConNode(final Connection con, final String connectionName) {
         this();
         this.connections.put(connectionName, con);
     }

     // ---------------------------------------------------------- Public methods

     /**
      * Add new connection
      * @param connection the connection to add
      * @param connectionName the name of the connection to add
      */
     public void addConnection(final Connection connection, final String connectionName) {
         this.connections.put(connectionName, connection);
     }

     /**
      * Gets the connectiont with the given name
      *
      * @param connection the name of the connection
      * @return the connection with the given name.<br/><code>null</code> if not exists.
      */
     public Connection getConnection(final String connectionName) {
         return (Connection)this.connections.get(connectionName);
     }

     /**
      * Gets the connections
      *
      * @return the connections
      */
     public Map getConnections() {
         return connections;
     }

     /**
      * Sets the connections
      *
      * @param  the connections
      */

     public void setConnections(Map connections) {
         this.connections = connections;
     }

 }
