/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package com.funambol.framework.core.dm.ddf;

import java.util.Hashtable;
import java.util.Map;


/**
 * Corresponds to the &lt;NAP&gt; interior node in the management tree
 *
 *
 *
 * @version $Id: NAP.java,v 1.1 2006/01/18 18:38:12 luigiafassina Exp $
 */
public class NAP {

    // --------------------------------------------------------------- Constants

    public static final String NAP_BEARER    = "/Bearer";
    public static final String NAP_ADDR_TYPE = "/AddrType";
    public static final String NAP_ADDR      = "/Addr";
    public static final String NAP_AUTH      = "/Auth";

    // ------------------------------------------------------------ Private data
    private String bearer;
    private String address;
    private String addressType;

    // contains all the pair id/secret for each authentication methods
    private Map auths;

    // ------------------------------------------------------------ Constructors
    /** For serialization purposes */
    public NAP() {
        this.auths = new Hashtable();
    }

    /**
     * Creates a new ConNAP object with the given parameters
     *
     * @param bearer the bearer type of the connection information
     * @param address the server address
     * @param addressType the type of the server address
     *
     */
    public NAP(final String bearer,
               final String address,
               final String addressType) {
        this();
        this.bearer      = bearer;
        this.address     = address;
        this.addressType = addressType;

    }

    // ---------------------------------------------------------- Public methods

    /**
     * Gets the bearer
     *
     * @return  the bearer
     */
    public String getBearer() {
        return bearer;
    }

    /**
     * Sets the bearer
     *
     * @param  the bearer
     */
    public void setBearer(String bearer) {
        this.bearer = bearer;
    }


    /**
     * Gets the address
     *
     * @return  the address
     */
    public String getAddress() {
        return address;
    }

    /**
     * Sets the address
     *
     * @param  the address
     */
    public void setAddress(String address) {
        this.address = address;
    }

    /**
     * Gets the addressType
     *
     * @return  the addressType
     */
    public String getAddressType() {
        return addressType;
    }

    /**
     * Sets the addressType
     *
     * @param  the addressType
     */
    public void setAddressType(String addressType) {
        this.addressType = addressType;
    }

    /**
     * Gets the <code>ConAuth</code> with the given name
     *
     * @return the auth with the given name
     */
    public Auth getAuth(String authenticationName) {
        return (Auth)auths.get(authenticationName);
    }

    /*
     * Gets the authentications available
     *
     * @return the authentications available
     */
    public Map getAuths() {
        return auths;
    }

    /*
     * Sets the auth
     *
     * @param  the auth
     */
    public void setAuths(Map auths) {
        this.auths = auths;
    }


    /**
     * Adds the auth
     *
     * @param  the auth to add
     */
    public void addAuth(Auth auth, String authenticationName) {
        auths.put(authenticationName, auth);
    }

}
