/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package com.funambol.framework.core.dm.ddf;

import java.beans.XMLEncoder;
import java.util.Map;
import java.util.HashMap;
import org.apache.commons.collections.map.ListOrderedMap;


/**
 * Corresponds to the &lt;SyncML DM&gt; management object
 *
 *
 *
 * @version $Id: SyncMLDM.java,v 1.1 2006/01/18 18:38:12 luigiafassina Exp $
 */

public class SyncMLDM implements java.io.Serializable {

    // --------------------------------------------------------------- Constants
   public static final String SYNCML_DM_BASE_URI    = "./SyncML";
   public static final String SYNCML_DM_DMACC       = "/DMAcc";
   public static final String SYNCML_DM_CON         = "/Con"  ;


   // ------------------------------------------------------------ Private data
   private DMAcc dmAcc;
   private ConNode con;


   // ------------------------------------------------------------ Constructors
   /** For serialization purposes */
   public SyncMLDM() {}

    /**
     * Creates a new SyncMLDM object with the given parameters
     *
     * @param dmAcc the dm account node
     * @param con the connection node
     *
     */
    public SyncMLDM(final DMAcc dmAcc,
                    final ConNode con) {
        this.dmAcc  = dmAcc;
        this.con    = con;
    }


    // ---------------------------------------------------------- Public methods

    /**
     * Gets the dmAcc
     *
     * @return  the dmAcc
     */
    public DMAcc getDmAcc() {
        return dmAcc;
    }

    /**
     * Sets the dmAcc
     *
     * @param  the dmAcc
     */
    public void setDmAcc(DMAcc dmAcc) {
        this.dmAcc = dmAcc;
    }

    /**
     * Gets the con
     *
     * @return  the con
     */
    public ConNode getCon() {
        return con;
    }

    /**
     * Sets the con
     *
     * @param  the con
     */
    public void setCon(ConNode con) {
        this.con = con;
    }


    /**
     * Used to test
     * @param args String[]
     */
    public static void main(String[] args) {
        SyncMLDM syncmlDm = new SyncMLDM();

        DMAcc acc = new DMAcc();
        Map accounts = new ListOrderedMap();

        DMAccount account = new DMAccount();
        accounts.put("AccountName", account);

        DMAccount account2 = new DMAccount();
        accounts.put("AccountName2", account2);
        account2.setAddressType(2);
        account2.setClientNonce(new byte[] {23,24,25,26});

        acc.setDMAccounts(accounts);
        syncmlDm.setDmAcc(acc);

        account.setConRef("ConnectionName");

        Ext ext = new Ext();
        ext.setNode("service", "5");

        XMLEncoder enc = new XMLEncoder(System.out);
        enc.writeObject(ext);
        enc.flush();
        enc.close();

        Map auths = new ListOrderedMap();
        Auth auth = new Auth("id", "secret");
        auths.put("auth-method", auth );
        NAP nap = new NAP("napBearer", "napAddress", "napAddressType");
        nap.setAuths(auths);

        Map authsPx = new ListOrderedMap();
        Auth authPx = new Auth("id", "secret");
        authsPx.put("auth-method", authPx );
        PX px = new PX("portNbr", "pxAddress", "pxAddressType");
        px.setAuths(authsPx);

        Connection con = new Connection(ext, nap, px);
        ConNode conNode = new ConNode(con, "ConnectionName");

        syncmlDm.setCon(conNode);

        enc = new XMLEncoder(System.out);
        enc.writeObject(syncmlDm);
        enc.flush();
        enc.close();
    }

}
