/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package com.funambol.framework.engine.dm;

import java.util.Date;

import java.io.Serializable;
import org.apache.commons.lang.builder.ToStringBuilder;

/**
 * This class represents the device's DM state.
 *
 *
 *
 * @version $Id: DeviceDMState.java,v 1.1 2006/01/18 18:38:12 luigiafassina Exp $
 *
 */
public class DeviceDMState implements Serializable {

    // --------------------------------------------------------------- Constants

    public static final byte STATE_UNKNOWN      = '-';
    public static final byte STATE_UNMANAGEABLE = 'U';
    public static final byte STATE_MANAGEABLE   = 'M';
    public static final byte STATE_NOTIFIED     = 'N';
    public static final byte STATE_IN_PROGRESS  = 'P';
    public static final byte STATE_COMPLETED    = 'C';
    public static final byte STATE_ERROR        = 'E';
    public static final byte STATE_ABORTED      = 'A';

    public static final String PROPERTY_STATE      = "state" ;
    public static final String PROPERTY_SESSION_ID = "mssid" ;
    public static final String PROPERTY_DEVICE_ID  = "device";

    // ------------------------------------------------------------- Public data

    public String id         ;
    public String deviceId   ;
    public String mssid      ;
    public byte   state      ;
    public Date   start      ;
    public Date   end        ;
    public String operation  ;
    public String info       ;

    // ------------------------------------------------------------- Costructors

    /** Creates a new instance of Sync4jDevice */
    public DeviceDMState() {
        init(null, null, STATE_UNKNOWN, null, null, null, null);
    }

    /**
     * Creates a new instance of Sync4jDevice for a give device
     *
     * @param deviceId the device id
     */
    public DeviceDMState(String deviceId) {
        init(deviceId, null, STATE_UNKNOWN, null, null, null, null);
    }

    // ---------------------------------------------------------- Public methods

    /**
     * Copies the given object into this.
     *
     * @param dms the DeviceDMState to copy from
     */
    public void copyFrom(DeviceDMState dms) {
        this.id        = dms.id       ;
        this.deviceId  = dms.deviceId ;
        this.mssid     = dms.mssid    ;
        this.state     = dms.state    ;
        this.start     = dms.start    ;
        this.end       = dms.end      ;
        this.operation = dms.operation;
        this.info      = dms.info     ;
    }
    // --------------------------------------------------------- Private methods

    /**
     * Init method.
     *
     * @param deviceId device id
     * @param mssid management server session id
     * @param state state
     * @param start session start
     * @param end session end
     * @param operation application specific management operation
     * @param info application specific details
     *
     */
    private void init(String deviceId ,
                      String mmsid    ,
                      byte   state    ,
                      Date   start    ,
                      Date   end      ,
                      String operation,
                      String info     ) {
        this.deviceId  = deviceId ;
        this.mssid     = mssid    ;
        this.state     = state    ;
        this.start     = start    ;
        this.end       = end      ;
        this.operation = operation;
        this.info      = info     ;
    }


    // -------------------------------------------------------------- toString()
    public String toString() {
        ToStringBuilder sb = new ToStringBuilder(this);

        sb.append("deviceId",  deviceId   );
        sb.append("mssid",     mssid      );
        sb.append("state",     (char)state);
        sb.append("start",     start      );
        sb.append("end",       end        );
        sb.append("operation", operation  );
        sb.append("info",      info       );

        return sb.toString();
    }

}
