/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package com.funambol.framework.engine.dm;

import java.util.Map;
import java.util.HashMap;

/**
 * This class represents the result of a single management operation.<br>
 * Note that differently by the Results comand, which can hold multiple results,
 * this object brings only one result.
 *
 *
 *
 * @version $Id: ManagementOperationResult.java,v 1.1 2006/01/18 18:38:12 luigiafassina Exp $
 */
public class ManagementOperationResult {
    // -------------------------------------------------------------- Properties

    /**
     * The status code of the requested operation
     */
    private int statusCode;

    /**
     * Sets statusCode
     *
     * @param statusCode the new statusCode
     */
    public void setStatusCode(int statusCode) {
        this.statusCode = statusCode;
    }

    /**
     * Gets statusCode
     *
     * @return the current statusCode value
     */
    public int getStatusCode() {
        return statusCode;
    }

    /**
     * The the requested command. One of "Add", "Copy", "Delete", "Exec",
     * "Get", "Replace", "Sequence", "Atomic"
     */
    private String command;

    /**
     * Sets command
     *
     * @param command the new command
     */
    public void setCommand(String command) {
        this.command = command;
    }

    /**
     * Gets command
     *
     * @return the current command value
     */
    public String getCommand() {
        return command;
    }

    /**
     * The nodes property. Note that it may contain results if the
     * ManagementOperationStatus regards a Get or a set of nodes if it relates
     * to a status of any command who specified items in it.
     */
    private Map nodes;

    /**
     * Returns the nodes property
     *
     * @return the nodes property
     */
    public Map getNodes() {
        return nodes;
    }

    /**
     * Set the nodes property
     *
     * @param newNodes the new values
     */
    public void setNodes(Map newNodes) {
        this.nodes = new HashMap();
        if (newNodes == null) {
            return;
        }

        nodes.putAll(newNodes);
    }

    /**
     * Addes the given nodes to the existing nodes. If no nodes were present,
     * a new hash map is created to store them.
     *
     * @param newNodes the new values
     */
    public void addNodes(Map newNodes) {
        if (nodes == null) {
            nodes = new HashMap();
        }

        nodes.putAll(newNodes);
    }

    // ------------------------------------------------------------ Constructors

    /** Creates a new instance of ManagementOperationResult */
    public ManagementOperationResult() {
        statusCode = -1;
        command = null;
        nodes = new HashMap();
    }

    // ---------------------------------------------------------- Public methods

}
