/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package com.funambol.framework.engine.dm;

import org.apache.commons.lang.builder.ToStringBuilder;

/**
 * Represents a node in dm tree.
 *
 * @version $Id: TreeNode.java,v 1.1 2006/01/18 18:38:12 luigiafassina Exp $
 */
public class TreeNode {

    // --------------------------------------------------------------- Constants

    public static final String FORMAT_BINARY  = "b64";
    public static final String FORMAT_CHR     = "chr";
    public static final String FORMAT_INT     = "int";
    public static final String FORMAT_BOOL    = "bool";
    public static final String FORMAT_NODE    = "node";
    public static final String FORMAT_XML     = "xml";
    public static final String FORMAT_NULL    = "null";
    public static final String FORMAT_DEFAULT_VALUE = FORMAT_CHR;

    public static final String TYPE_DEFAULT_VALUE = "text/plain";


    // -------------------------------------------------------------- Properties
    private String name   = null;
    private String format = null;
    private String type   = null;
    private Object value  = null;

    // ------------------------------------------------------------- Constructor

    public TreeNode() {
        this.type = TYPE_DEFAULT_VALUE;
    }

    public TreeNode(String name) {
        this();
        this.name = name;
    }

    public TreeNode(String name, Object value) {
        this(name);
        setValue(value);
    }

    public TreeNode(String name, Object value, String format) {
        this(name, value);
        this.format = format;
    }

    public TreeNode(String name, Object value, String format, String type) {
        this(name, value, format);
        this.type = type;
    }

    // ----------------------------------------------------------- Public Methods

    /**
     * Returns the name property
     *
     * @return the name property
     */
    public String getName() {
        return name;
    }

    /**
     * Set the name property
     *
     * @param name the new name
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * Returns the value property
     *
     * @return the value property
     */
    public Object getValue() {
        return value;
    }

    /**
     * Set the value property
     *
     * @param value the new value
     */
    public void setValue(Object value) {
        this.value = value;

        if (value != null) {
            if (value instanceof byte[]) {
                this.format = FORMAT_BINARY;
            } else if (value instanceof Boolean) {
                this.format = FORMAT_BOOL;
            } else if (value instanceof Integer) {
                this.format = FORMAT_INT;
            } else {
                this.format = FORMAT_DEFAULT_VALUE;
            }
        }
    }

    /**
     * Returns the format property
     *
     * @return the format property
     */
    public String getFormat() {
        return format;
    }

    /**
     * Set the format property
     *
     * @param format the new format
     */
    public void setFormat(String format) {
        this.format = format;
    }


    /**
     * Returns the type property
     *
     * @return the type property
     */
    public String getType() {
        return type;
    }

    /**
     * Set the type property
     *
     * @param type the new type
     */
    public void setType(String type) {
        this.type = type;
    }

    /**
     * Returns a String representation of this TreeNode
     * @return String
     */
    public String toString() {
        ToStringBuilder sb = new ToStringBuilder(this);

        sb.append("name"  , name);
        sb.append("value" , value);
        sb.append("format", format);
        sb.append("type"  , type);

        return sb.toString();
    }
}
