/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package com.funambol.framework.notification;


/**
 *
 *
 *
 * @version $Id: Sender.java,v 1.1 2006/01/18 18:38:12 luigiafassina Exp $
 */
public interface Sender {


    // ---------------------------------------------------------- Public Methods

    /**
     * Sends a message
     * @param messageType the type of the message. See {@link NotificationConstants}
     * @param phoneNumber the phone number of the target device
     * @param message the messagge to send
     * @param info application specific info
     * @throws NotificationException
     */
    public void sendMessage(int    messageType,
                            String phoneNumber,
                            byte[] message,
                            String info) throws NotificationException;

    /**
     * Sends messages
     * @param messageType the type of the message. See {@link NotificationConstants}
     * @param phoneNumbers the phone numbers list of the target device
     * @param messages the messages to send
     * @param info application specific info
     * @throws NotificationException
     */
    public void sendMessages(int      messageType,
                             String[] phoneNumbers,
                             byte[][] message,
                             String   info) throws NotificationException;


    /**
     * Sends more messages
     * @param messageType the type of the message. See {@link NotificationConstants}
     * @param contentType the contentType
     * @param macs the macs list
     * @param authMethods the authentication methods
     * @param phoneNumbers the phone number list
     * @param messages the messages to send
     * @param info application specific info
     * @throws NotificationException
     */
    public void sendMessages(int      messageType,
                             String   contentType,
                             String[] macs,
                             int[]    authMethods,
                             String[] phoneNumbers,
                             byte[][] messages,
                             String   info) throws NotificationException;


}
