/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package com.funambol.framework.tools;

import com.funambol.framework.tools.IdGenerator;

/**
 * This class implements an ID generator, that increments the counter each time
 * the next method is called. When the maximum 16 bit integer si reached, it
 * starts again from 1. The first retuned number is 1.
 * <p>
 * SimpleIdGenerator is thread-safe
 *
 * @version $Id: Int16IdGenerator.java,v 1.1 2006/01/18 18:38:13 luigiafassina Exp $
 */
public final class Int16IdGenerator implements IdGenerator, java.io.Serializable {

    // -------------------------------------------------------------- Properties

    /**
     * The counter
     */
    private int counter;

    public int getCounter() {
        return counter;
    }

    // ------------------------------------------------------------ Constructors

    /**
     * Creates a new instance of SimpleIdGenerator
     *
     * @param counter the starting value
     * @param increment the increment
     */
    public Int16IdGenerator() {
        counter = 0;
    }

    /**
     * Reset the generator to 0.
     */
    public void reset() {
        counter = 0;
    }

    /**
     * Returns the next value of the counter (incrementing the counter by the
     * increment)
     *
     * @return the next generated value
     */
    public synchronized String next() {
        if (counter == 0x0000ffff) {
            reset();
        }

        return String.valueOf(++counter);
    }

    /**
     * Returns the last generated id (which is the current id).
     *
     * @return the last generated id
     */
    public synchronized String current() {
        return String.valueOf(counter);
    }
}
