/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


package com.funambol.server.engine;

import java.util.logging.Logger;
import java.util.logging.Level;

import com.funambol.framework.core.SyncML;
import com.funambol.framework.core.Sync4jException;
import com.funambol.framework.config.Configuration;
import com.funambol.framework.config.ConfigurationConstants;
import com.funambol.framework.logging.FunambolLogger;
import com.funambol.framework.logging.FunambolLoggerName;

import com.funambol.framework.engine.pipeline.OutputMessageProcessor;
import com.funambol.framework.engine.pipeline.MessageProcessingContext;

/**
 * This class implements a synclet that adds the RespURI tag to the message.
 *
 *.com
 */
public class RespURISynclet
implements OutputMessageProcessor {
    // --------------------------------------------------------------- Constants

    public static final String PARAM_SESSION_ID = "sid";

    // ------------------------------------------------------------ Private data

    private static final Logger log = FunambolLogger.getLogger(FunambolLoggerName.ENGINE);

    // ------------------------------------------------------------ Constructors


    // -------------------------------------------------- OutputMessageProcessor

    public void postProcessMessage(MessageProcessingContext processingContext,
                                   SyncML                   message          )
    throws Sync4jException {
        Configuration config = Configuration.getConfiguration();

        String sessionId =
            (String)processingContext.getProperty(processingContext.PROPERTY_SESSIONID);

        if (sessionId == null) {
            if (log.isLoggable(Level.INFO)) {
                log.info(processingContext.PROPERTY_SESSIONID + " is null! Synclet ignored");
            }
            return;
        }

        String serverUri =
            config.getStringValue(ConfigurationConstants.CFG_SERVER_URI);

        message.getSyncHdr().setRespURI(
            serverUri                    +
            '?'                          +
            PARAM_SESSION_ID             +
            '='                          +
            sessionId
        );
    }
}
