/**
 * Copyright (C) 2003-2006 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


package com.funambol.server.engine.dm.ejb;

import java.rmi.RemoteException;

import com.funambol.framework.engine.dm.ManagementException;
import com.funambol.framework.notification.NotificationException;

/**
  *
  *
  * @version $Id: ManagementRemote.java,v 1.1 2006/01/18 18:38:17 luigiafassina Exp $
  *
  */
public interface ManagementRemote extends javax.ejb.EJBObject
 {

     /**
      * Performs a bootstrap with the given parameter
      * @param messageType the type of the message. See {@link NotificationConstants}
      * @param transportType the type of the transport. See {@link NotificationConstants}
      * @param deviceUri the device uri
      * @param phoneNumber the phone number of the device
      * @param username the user name with which the device will do the next device management
      * @param password the password with which the device will do the next device management
      * @param info application specific info
      *
      * @throws RemoteException if a error occurs
      */
     public void bootstrap(int messageType, int transportType, String deviceUri, String phoneNumber, String
                            username, String password, String info)
     throws RemoteException, NotificationException, ManagementException;



    /**
     * Sends a notification message to the device with the given phoneNumber
     * @param messageType the type of the notification message as define in <code>NotificationConstants<code>
     * @param transportType the type of the transport as define in <code>NotificationConstants<code>
     * @param phoneNumber the phone number
     * @param operation application specific operation to be performed
     * @param info application specific detail information
     *
     * @throws NotificationException in case of errors
     */
    public void sendNotification( int messageType     ,
                                  int transportType   ,
                                  String phoneNumber  ,
                                  String operation    ,
                                  String info         )
    throws RemoteException, NotificationException, ManagementException;

    /**
     * Executes the management sequence identified by the given operation name.
     *
     * @param phoneNumber the phone number
     * @param operation the management operation name
     * @param info application specific detail information
     *
     * @throws RemoteException in case of RMI errors,
     *         ManagementException if a error occurs in the management engine,
     *         NotificationException if an error occurs in the notification process
     */
    public void executeManagementOperation( String phoneNumber  ,
                                            String operation    ,
                                            String info         )
    throws RemoteException, ManagementException, NotificationException;


 }
